@@ -1,12 +1,15 @@
 from collections.abc import Callable
-from itertools import combinations, starmap
+from itertools import chain, combinations, starmap
 
 from mypy.nodes import (
     Block,
     CallExpr,
     ComparisonExpr,
     DictExpr,
+    DictionaryComprehension,
     Expression,
+    ForStmt,
+    GeneratorExpr,
     IndexExpr,
     ListExpr,
     MemberExpr,
@@ -61,6 +64,40 @@ def check_block_like(
             func(node.defs, errors)
 
 
+def check_for_loop_like(
+    func: Callable[[Node, Node, list[Node], list[Error]], None],
+    node: ForStmt | GeneratorExpr | DictionaryComprehension,
+    errors: list[Error],
+) -> None:
+    match node:
+        case ForStmt(index=index, expr=expr):
+            func(index, expr, [], errors)
+
+        case GeneratorExpr(
+            indices=[index],
+            sequences=[expr],
+            condlists=condlists,
+        ):
+            func(
+                index,
+                expr,
+                list(chain([node.left_expr], *condlists)),
+                errors,
+            )
+
+        case DictionaryComprehension(
+            indices=[index],
+            sequences=[expr],
+            condlists=condlists,
+        ):
+            func(
+                index,
+                expr,
+                list(chain([node.key, node.value], *condlists)),
+                errors,
+            )
+
+
 def unmangle_name(name: str | None) -> str:
     return (name or "").replace("'", "")
 
@@ -148,7 +185,7 @@ def get_common_expr_positions(*exprs: Expression) -> tuple[int, int] | None:
 
 
 def get_common_expr_in_comparison_chain(
-    node: OpExpr, oper: str
+    node: OpExpr, oper: str, cmp_oper: str = "=="
 ) -> tuple[Expression, tuple[int, int]] | None:
     """
     This function finds the first expression shared between 2 comparison
@@ -169,9 +206,12 @@ def get_common_expr_in_comparison_chain(
 
     match extract_binary_oper(oper, node):
         case (
-            ComparisonExpr(operators=["=="], operands=[a, b]),
-            ComparisonExpr(operators=["=="], operands=[c, d]),
-        ) if indices := get_common_expr_positions(a, b, c, d):
+            ComparisonExpr(operators=[lhs_oper], operands=[a, b]),
+            ComparisonExpr(operators=[rhs_oper], operands=[c, d]),
+        ) if (
+            lhs_oper == rhs_oper == cmp_oper
+            and (indices := get_common_expr_positions(a, b, c, d))
+        ):
             return a, indices
 
     return None  # pragma: no cover
@@ -192,3 +232,37 @@ class ReadCountVisitor(TraverserVisitor):
     @property
     def was_read(self) -> int:
         return self.read_count > 0
+
+
+def is_placeholder(name: NameExpr) -> bool:
+    return unmangle_name(name.name) == "_"
+
+
+def is_name_unused_in_contexts(name: NameExpr, contexts: list[Node]) -> bool:
+    if not contexts:
+        return False
+
+    for ctx in contexts:
+        visitor = ReadCountVisitor(name)
+        ctx.accept(visitor)
+
+        if visitor.was_read:
+            return False
+
+    return True
+
+
+def normalize_os_path(module: str) -> str:
+    """
+    Mypy turns "os.path" module names into their respective platform, such
+    as "ntpath" for windows, "posixpath" if they are POSIX only, or
+    "genericpath" if they apply to both (I assume). To make life easier
+    for us though, we turn those module names into their original form.
+    """
+
+    segments = module.split(".")
+
+    if segments[0].startswith(("genericpath", "ntpath", "posixpath")):
+        return ".".join(["os", "path"] + segments[1:])
+
+    return module
