@@ -2,6 +2,7 @@ from dataclasses import dataclass
 
 from mypy.nodes import CallExpr, MemberExpr, NameExpr
 
+from refurb.checks.common import normalize_os_path
 from refurb.checks.pathlib.util import is_pathlike
 from refurb.error import Error
 
@@ -31,6 +32,7 @@ class ErrorInfo(Error):
     ```
     """
 
+    name = "use-pathlib-exists"
     code = 141
     categories = ["pathlib"]
 
@@ -40,7 +42,7 @@ def check(node: CallExpr, errors: list[Error]) -> None:
         case CallExpr(
             callee=(MemberExpr() | NameExpr()) as expr,
             args=[arg],
-        ) if expr.fullname == "genericpath.exists":
+        ) if normalize_os_path(expr.fullname or "") == "os.path.exists":
             replace = "x.exists()" if is_pathlike(arg) else "Path(x).exists()"
 
             errors.append(
